diff --git a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/Dialogs/AboutDialog.cs b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/Dialogs/AboutDialog.cs
index fa14f2f6..6ed71464 100644
--- a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/Dialogs/AboutDialog.cs
+++ b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/Dialogs/AboutDialog.cs
@@ -20,7 +20,7 @@
// along with this program. If not, see .
using System;
using UniversalEditor.UserInterface;
-namespace UniversalEditor.Engines.GTK
+namespace UniversalEditor.Engines.GTK.Dialogs
{
public partial class AboutDialog : Gtk.Dialog
{
diff --git a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/GTKEngine.cs b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/GTKEngine.cs
index f47ed4f9..08e299e4 100644
--- a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/GTKEngine.cs
+++ b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/GTKEngine.cs
@@ -27,6 +27,13 @@ namespace UniversalEditor.Engines.GTK
mw.Show ();
return mw;
}
+
+ public override void ShowAboutDialog()
+ {
+ Dialogs.AboutDialog dlg = new Dialogs.AboutDialog();
+ dlg.Run();
+ dlg.Destroy();
+ }
}
}
diff --git a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/MainWindow.cs b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/MainWindow.cs
index fc6bd252..7948614a 100644
--- a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/MainWindow.cs
+++ b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/MainWindow.cs
@@ -429,6 +429,13 @@ namespace UniversalEditor.Engines.GTK
{
throw new System.NotImplementedException ();
}
+
+ public void ShowAboutDialog()
+ {
+ Dialogs.AboutDialog dlg = new Dialogs.AboutDialog();
+ dlg.Run();
+ dlg.Destroy();
+ }
#endregion
}
}
\ No newline at end of file
diff --git a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/UniversalEditor.Engines.GTK.csproj b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/UniversalEditor.Engines.GTK.csproj
index 3e70e45b..0e55ccc5 100644
--- a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/UniversalEditor.Engines.GTK.csproj
+++ b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/UniversalEditor.Engines.GTK.csproj
@@ -69,7 +69,7 @@
-
+
diff --git a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/gui.stetic b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/gui.stetic
index dfe39ad1..bfe65c31 100644
--- a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/gui.stetic
+++ b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/gui.stetic
@@ -264,7 +264,7 @@
-
+
About [ApplicationTitle]
CenterOnParent
diff --git a/CSharp/Libraries/UniversalEditor.UserInterface/Engine.cs b/CSharp/Libraries/UniversalEditor.UserInterface/Engine.cs
index 8b0713bc..8bce0361 100644
--- a/CSharp/Libraries/UniversalEditor.UserInterface/Engine.cs
+++ b/CSharp/Libraries/UniversalEditor.UserInterface/Engine.cs
@@ -240,6 +240,12 @@ namespace UniversalEditor.UserInterface
});
#endregion
#region Help
+ AttachCommandEventHandler("HelpAboutPlatform", delegate(object sender, EventArgs e)
+ {
+ ShowAboutDialog();
+ });
+ #endregion
+ #region Help
Command helpAboutPlatform = mvarCommands["HelpAboutPlatform"];
if (helpAboutPlatform != null)
{
@@ -380,6 +386,8 @@ namespace UniversalEditor.UserInterface
/// The file name(s) of the document(s) to load.
/// An representing the window that was created.
protected abstract IHostApplicationWindow OpenWindowInternal(params string[] FileNames);
+
+ public abstract void ShowAboutDialog();
///
/// Opens a new window, optionally loading the specified documents.
diff --git a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/UniversalEditor.Engines.GTK.AboutDialog.cs b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/UniversalEditor.Engines.GTK.Dialogs.AboutDialog.cs
similarity index 97%
rename from CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/UniversalEditor.Engines.GTK.AboutDialog.cs
rename to CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/UniversalEditor.Engines.GTK.Dialogs.AboutDialog.cs
index 7522a765..14b9baea 100644
--- a/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/UniversalEditor.Engines.GTK.AboutDialog.cs
+++ b/CSharp/Engines/GTK/UniversalEditor.Engines.GTK/gtk-gui/UniversalEditor.Engines.GTK.Dialogs.AboutDialog.cs
@@ -1,6 +1,6 @@
// This file has been generated by the GUI designer. Do not modify.
-namespace UniversalEditor.Engines.GTK
+namespace UniversalEditor.Engines.GTK.Dialogs
{
public partial class AboutDialog
{
@@ -37,12 +37,12 @@ namespace UniversalEditor.Engines.GTK
protected virtual void Build ()
{
global::Stetic.Gui.Initialize (this);
- // Widget UniversalEditor.Engines.GTK.AboutDialog
- this.Name = "UniversalEditor.Engines.GTK.AboutDialog";
+ // Widget UniversalEditor.Engines.GTK.Dialogs.AboutDialog
+ this.Name = "UniversalEditor.Engines.GTK.Dialogs.AboutDialog";
this.Title = global::Mono.Unix.Catalog.GetString ("About [ApplicationTitle]");
this.WindowPosition = ((global::Gtk.WindowPosition)(4));
this.Resizable = false;
// Internal child UniversalEditor.Engines.GTK.AboutDialog.VBox
global::Gtk.VBox w1 = this.VBox;
w1.Name = "dialog1_VBox";
w1.BorderWidth = ((uint)(2));
@@ -234,7 +234,7 @@ namespace UniversalEditor.Engines.GTK
w1.Add (this.vbox3);
global::Gtk.Box.BoxChild w23 = ((global::Gtk.Box.BoxChild)(w1 [this.vbox3]));
w23.Position = 0;
// Internal child UniversalEditor.Engines.GTK.AboutDialog.ActionArea
global::Gtk.HButtonBox w24 = this.ActionArea;
w24.Name = "dialog1_ActionArea";
w24.Spacing = 10;
@@ -37,12 +37,12 @@ namespace UniversalEditor.Engines.GTK
this.WindowPosition = ((global::Gtk.WindowPosition)(4));
this.Resizable = false;
- // Internal child UniversalEditor.Engines.GTK.AboutDialog.VBox
+ // Internal child UniversalEditor.Engines.GTK.Dialogs.AboutDialog.VBox
global::Gtk.VBox w1 = this.VBox;
w1.Name = "dialog1_VBox";
@@ -234,7 +234,7 @@ namespace UniversalEditor.Engines.GTK
global::Gtk.Box.BoxChild w23 = ((global::Gtk.Box.BoxChild)(w1 [this.vbox3]));
w23.Position = 0;
- // Internal child UniversalEditor.Engines.GTK.AboutDialog.ActionArea
+ // Internal child UniversalEditor.Engines.GTK.Dialogs.AboutDialog.ActionArea
global::Gtk.HButtonBox w24 = this.ActionArea;
w24.Name = "dialog1_ActionArea";